## NOTES DURING DEVELOPMENT


### Discussed on Monday 10th July
- **(closed)** Class structure: main TRBS class
- **(closed)** Evaluate structure: evaluate_all_scenarios() --> evaluate_selected_scenario() --> evaluate_all_dependencies()--> 
evaluate_single_dependency()
- (open) Destination is NOT ALLOWED to be equal to argument 
- **(closed)** Remove intermediates (can be introduced in dependencies)
- (open) Move range protection to dependencies 
- (open) Nices to have: Optimizer / Category / Key Output graph

### Discussed on Wednesday 19th July
- **(closed)** Remove units
- **(closed)** remove `starts_with("key_output")`
- **(closed)** Renaming: TheResponsibleBusinessSimulator, trbs, analyze_case
- **(closed)** Visualize class: Bar charts  step 6 (stacked) and step 7 (singular), appreciation table and value